from setuptools import setup

setup(
    name='ioStandard',
    version='0.2.3',
    author='Austin Gilchrist-Thomas',
    packages=['ioStandard'],
    install_requires=['pygame', 'datetime', 'tk'],
)